@@ -11,7 +11,7 @@ from os import path
 import pathlib
 import re
 import subprocess
-from typing import Collection, Dict, List, Optional, Tuple, Union
+from typing import Collection, Dict, List, Optional, Tuple, Union, cast
 
 import psycopg2
 import psycopg2.errors
@@ -143,7 +143,7 @@ def swh_db_versions(
             )
             try:
                 c.execute(query)
-                return c.fetchall()
+                return cast(List[Tuple[int, datetime, str]], c.fetchall())
             except psycopg2.errors.UndefinedTable:
                 return None
     except Exception:
@@ -185,9 +185,12 @@ def swh_db_upgrade(
         if db_version < int(fname.stem) <= to_version
     ]
 
+    if not sqlfiles:
+        return db_version
+
     for sqlfile in sqlfiles:
         new_version = int(path.splitext(path.basename(sqlfile))[0])
-        logger.info("Executing migration script {sqlfile}")
+        logger.info("Executing migration script '%s'", sqlfile)
         if db_version is not None and (new_version - db_version) > 1:
             logger.error(
                 f"There are missing migration steps between {db_version} and "
